@@ -2,8 +2,8 @@ using System;
 using System.Reflection;
 using System.Runtime.CompilerServices;
 
-[assembly: ApplicationVersion ("2.3.4", "2.3.4")]
-[assembly: ApplicationBuildInformation ("git-checkout", "freebsd9.0", "amd64", "2012-01-19 19:26:23 MYT")]
+[assembly: ApplicationVersion ("2.3.5", "2.3.5")]
+[assembly: ApplicationBuildInformation ("git-checkout", "linux-gnu", "x86_64", "2012-02-15 21:33:08 CET")]
 
 [assembly: AssemblyVersion ("2.3.0.0")]
 [assembly: AssemblyTitle ("Banshee")]
